@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: free
 version: 4.12.4
-id: free-4.12.4-f8dab736d0d811e91eb50084b5673f3a
-key: free_7TQQfH6SOOb62MYhmoGomT
+id: free-4.12.4-5e68614777ed20792496ad931a527625
+key: free_2pxEc9u9SL8JsgJqFaZpKy
 license: BSD3
 copyright: Copyright (C) 2008-2015 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -45,18 +45,18 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/free-4.12.4
 library-dirs: /usr/lib/ghc-7.10.3/site-local/free-4.12.4
 data-dir: /usr/share/arm-linux-ghc-7.10.3/free-4.12.4
-hs-libraries: HSfree-4.12.4-7TQQfH6SOOb62MYhmoGomT
+hs-libraries: HSfree-4.12.4-2pxEc9u9SL8JsgJqFaZpKy
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    bifunctors-5.3-b6e9a28a0175204e65003b150c0bbe80
-    comonad-5-3b2e208311908bc5a9db1ceb26126917
+    bifunctors-5.3-332d0b68f126b9a85f3a8ae905feb67c
+    comonad-5-eb230ef163a26fe6410daceeb92d736a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     distributive-0.5.0.2-062a0a4262c71bd1a32922e0774f8a66
     exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     prelude-extras-0.4.0.3-1ebda3e30d44e52e3bbcd33027a32ddc
-    profunctors-5.2-026a1eb9905bccdb097d36481584da83
-    semigroupoids-5.0.1-ab1721c6c7a72801e6cd851407a313ad
+    profunctors-5.2-1a11bf84af8321e4318303d34ccac042
+    semigroupoids-5.0.1-9020d584fd071e35efe756eb398e9c78
     semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
